-- Fancy Pants Man's Head
-- Freeslot and slot declaration.
freeslot(
-- Normal Hair
"SPR_FPSN",
"SPR_FPSL",
"SPR_FPSR",
-- Dither Hair
"SPR_FPMN",
"SPR_FPML",
"SPR_FPMR",
-- Drift Hair
"SPR_FPDA",
"SPR_FPDB",
-- State
"S_FANCYHEAD")

states[S_FANCYHEAD] = {
	sprite = SPR_FPSN,
	frame = 0,
	tics = -1,
	action = nil,
	var1 = 0,
	var2 = 0,
	nextstate = S_FANCYHEAD
}

-- "Constants"
local FANCYHEAD_IDLE = 0
local FANCYHEAD_SLOW = 4
local FANCYHEAD_FAST = 8
local FANCYHEAD_BACK = 12
local FANCYHEAD_SIDEL = 16
local FANCYHEAD_SIDER = 20
local FANCYHEAD_FALL = 24

-- Functions

local function fancyhead_spawn(p)
	local pmo = p.mo
	if(pmo.skin ~= "fancypantsman")then return end
	local mo = P_SpawnMobjFromMobj(pmo,0,0,0,MT_THOK)
	mo.state = S_FANCYHEAD
	mo.target = pmo
end

local function fancyhead_postthink()
	-- I would have made a separate object to use mobjthinker
	-- but like i want this to work in post think so it's sure to be
	-- after all other objects and fancy doesn't get his head severed
	-- so there's no point for a custom object.
	
	-- Also so i can double check i didn't mess up and make 2
	local playerlist = {}
	for mo in mobjs.iterate() do
		if(mo.type ~= MT_THOK)then continue end
		if(mo.state ~= S_FANCYHEAD)then continue end
		if(not mo.target or not mo.target.valid)then
			mo.state = S_NULL
			continue 
		end
		if(mo.target.skin ~= "fancypantsman")then
			mo.state = S_NULL
			continue
		end
		for i,p in pairs(playerlist) do
			if(p == mo.target.player)then
				mo.state = S_NULL
				break
			end
		end
		if(not mo.valid)then continue end
		table.insert(playerlist,mo.target.player)
		mo.hairtime = $ or 1
		local pmo,p = mo.target,mo.target.player
		-- Hide in specific animations
		if((pmo.state >= S_KART_STILL and pmo.state <= S_KART_STILL_LOOK_R) or
		pmo.state >= S_KART_SPINOUT)then
			mo.renderflags = $|RF_DONTDRAW
			mo.hairtime = 0
		else
			mo.renderflags = (pmo.renderflags&RF_DONTDRAW) and ($|RF_DONTDRAW) or ($&~RF_DONTDRAW)
		end
		-- Set position and color
		P_MoveOrigin(mo,pmo.x,pmo.y,pmo.z)
		
		mo.angle = pmo.angle
		mo.spriteroll = pmo.spriteroll
		mo.pitch = pmo.pitch
		mo.roll = pmo.roll
		
		mo.spritexscale = pmo.spritexscale
		mo.spriteyscale = pmo.spriteyscale
		mo.spritexoffset = pmo.spritexoffset
		mo.spriteyoffset = pmo.spriteyoffset
		
		mo.color = pmo.color
		mo.colorized = pmo.colorized
		mo.blendmode = pmo.blendmode
		mo.alpha = pmo.alpha
		
		P_SetScale(mo,pmo.scale)
		-- Looking
		if(pmo.state == S_KART_SLOW_GLANCE_L or
		pmo.state == S_KART_FAST_GLANCE_L)then
			mo.angle = $+ANGLE_45
		end
		if(pmo.state == S_KART_SLOW_GLANCE_R or
		pmo.state == S_KART_FAST_GLANCE_R)then
			mo.angle = $-ANGLE_45
		end
		if(pmo.state == S_KART_SLOW_LOOK_L or
		pmo.state == S_KART_FAST_LOOK_L)then
			mo.angle = $+ANGLE_90
		end
		if(pmo.state == S_KART_SLOW_LOOK_R or
		pmo.state == S_KART_FAST_LOOK_R)then
			mo.angle = $-ANGLE_90
		end
		local this_time,framestart,spritetouse = (mo.hairtime),FANCYHEAD_IDLE,SPR_FPSN
		-- Consider what sprite set to use
		if(pmo.state == S_KART_SLOW or (pmo.state >= S_KART_SLOW_GLANCE_L and pmo.state <= S_KART_SLOW_LOOK_R))then
			if(pmo.frame == 0)then spritetouse = SPR_FPMN end
		elseif(pmo.state == S_KART_SLOW_L)then
			spritetouse = (pmo.frame == 0) and SPR_FPML or SPR_FPSL
		elseif(pmo.state == S_KART_FAST_L)then
			spritetouse = SPR_FPSL
		elseif(pmo.state == S_KART_SLOW_R)then
			spritetouse = (pmo.frame == 0) and SPR_FPMR or SPR_FPSR
		elseif(pmo.state == S_KART_FAST_R)then
			spritetouse = SPR_FPSR
		elseif(pmo.state == S_KART_DRIFT_L_OUT or pmo.state == S_KART_DRIFT_R_OUT)then
			if(pmo.frame == 0)then 
				spritetouse = SPR_FPMN
				mo.spriteyoffset = $+(2<<FRACBITS)
			end
		elseif(pmo.state == S_KART_DRIFT_L_IN or pmo.state == S_KART_DRIFT_R_IN)then
			if(pmo.frame == 2)then 
				spritetouse = SPR_FPDA
			elseif(pmo.frame == 0)then
				spritetouse = SPR_FPDB
			end
		end
		-- Consider what frame and time to use
		-- Check Z first
		if(abs(pmo.momz) > p.speed and abs(pmo.momz) > (5*pmo.scale))then
			if(pmo.momz > 0)then
				framestart = FANCYHEAD_BACK
			else
				framestart = FANCYHEAD_FALL
			end
		else
			if(p.speed > (10*pmo.scale))then
				-- We are fast enough, change the hair
				-- Calculate movement angle
				local max_speed = abs(pmo.momx) + abs(pmo.momy)
				if(max_speed ~= 0)then
					local move_angle = mo.angle-R_PointToAngle2(0,0,FixedDiv(pmo.momx,max_speed)*1000,FixedDiv(pmo.momy,max_speed)*1000)
					local move_sin,move_cos = sin(move_angle),cos(move_angle)
					-- Check if we are moving forward/backward first.
					if(abs(move_sin) < FRACUNIT/2)then
						if(move_cos > 0)then
							if(p.speed <= (20*pmo.scale))then
								framestart = FANCYHEAD_SLOW
							else
								framestart = FANCYHEAD_FAST
							end
						else
							framestart = FANCYHEAD_BACK
						end
					else
						if(move_sin < 0)then
							framestart = FANCYHEAD_SIDEL
						else
							framestart = FANCYHEAD_SIDER
						end
					end
				end
			end
		end
		-- Set frame and add to time
		mo.sprite = spritetouse
		mo.frame = (this_time%4)+framestart
		mo.hairtime = $+1
	end
end

-- Hooks

addHook("PlayerSpawn",fancyhead_spawn)
addHook("PostThinkFrame",fancyhead_postthink)