--[[ SUPER SONIC INIT ]]--
--[[ Freeslot & Init ]]--

cfChars.supersonic = {}
local ss = cfChars.supersonic

--[[ Commands/Values ]]--
local cvar_numlaps = CV_FindVar("numlaps")

--[[ Local Constants ]]--
local sound_transform = sfx_s25f
local sound_untransform = sfx_s3k40
local sound_ringloss = sfx_kc2c

--[[ Base Functions ]]--

function ss.mapLoad(m)
	if(gametype ~= GT_RACE)then return end
	for p in players.iterate do
		if(not p.valid)then continue end
		p.ssonicvars = nil
		if(skins[p.skin].name == "ssonic")then
			ss.initIntro(p)
		end
	end
end

function ss.prethink(p)
	if(p.exiting)then return end
	if(not cheatThisRace)then return end
	if(not p.ssonicvars)then return end
	if(not p.ssonicvars.superInit)then return end
	local mo,sv = p.mo,p.ssonicvars
	if(sv.notSuper)then return end
	if(leveltime <= starttime)then return end
	-- Set Invincibilty
	p.invincibilitytimer = max((p.rings + sv.bonusRings) * 2,3)
end

function ss.think(p)
	if(p.exiting)then return end
	-- Define super sonic varssound_ringloss
	p.ssonicvars = $ or {
		bonusRings		= 30, -- This is how we go past 20 (and 128)
		tic				= TICRATE,
		transformTics	= 0, -- Flash!
		-- RingBurst
		ringBurst		= 0,
		ticsTilBurst	= 0,
	}
	local mo,sv = p.mo,p.ssonicvars
	-- Intro!!
	if(leveltime <= starttime and gametype == GT_RACE)then
		mo.skin = "sonic"
		if(leveltime == starttime)then
			sv.transformTics = 10
			S_StartSound(mo,sound_transform)
			mo.skin = "ssonic"
		end
	end
	-- Cheats go past this point
	if(not cheatThisRace)then return end
	if(not sv.superInit)then 
		p.rings = 20 
		sv.superInit = true
	end
	-- For losing rings after you go into a pit
	if(sv.bonusRings > 0)then
		sv.ringBurst = min(sv.ringBurst,sv.bonusRings + p.rings)
		if(sv.ticsTilBurst > 0)then
			sv.ticsTilBurst = $-1
		elseif(sv.ringBurst > 0)then
			S_StartSound(mo,sound_ringloss)
			sv.bonusRings = $-sv.ringBurst
			if(sv.bonusRings < 0)then
				p.rings = $ + sv.bonusRings
				sv.bonusRings = 0
			end
			cfChars.ringBurst(mo,sv.ringBurst)
			sv.ringBurst = 0
		end
	else
		sv.ringBurst = 0
		sv.ticsTilBurst = 0
	end
	if(sv.notSuper)then
		mo.skin = "sonic"
		-- Ability to transform back into super!
		-- Just collect 50 rings!
		if(sv.bonusRings >= 30)then
			sv.transformTics = 10
			S_StartSound(mo,sound_transform)
			mo.skin = "ssonic"
			sv.notSuper = nil
		end
	elseif(leveltime > starttime)then
		mo.skin = "ssonic"
		-- Do ticker stuff
		if(not p.respawn.state and p.playerstate == PST_LIVE and mo.hitlag <= 0)then
			-- Lose rings every second!
			sv.tic = $ - 1
			if(sv.tic <= 0)then
				sv.tic = TICRATE
				if(p.rings <= 0)then
					-- Daredevil mode == perma death
					if(cheatThisRace == 2)then
						-- Force the player to die
						P_DamageMobj(mo,mo,mo,99999,DMG_INSTAKILL)
						--player.rings = 20
						return
					end
					-- If we're not in evil mode then we will just change super sonic to sonic until we collect 50 rings.
					sv.notSuper = true
					mo.skin = "sonic"
					p.rings = 1
					S_StartSound(mo,sound_untransform)
				end
				-- Make it a little more fair to other players :3
				--P_PlayerRingBurst(p,1)
				-- Shields break this, so write our own ring burst
				p.rings = $-1
				local new_mo = P_SpawnMobjFromMobj(mo,0,0,0,MT_FLINGRING)
				local thrust = (13 * new_mo.scale);
				P_InstaThrust(new_mo,mo.angle + ANGLE_180,thrust)
				new_mo.threshold = 10
			end
		end
	end
	-- Be able to use ring pool
	if(sv.bonusRings > 0)then
		if(p.rings < 20)then
			sv.bonusRings = $ - (20 - p.rings)
			p.rings = 20
		end
	end
	-- Ring Rewards
	if(cheatThisRace == 2 and p.ssonicvars.bonusRings >= 30)then return end
	if(p.superring and p.nextringaward == 0 and (p.rings >= 20 or sv.bonusRings > 0))then sv.bonusRings = $ + 1 end
end

function ss.postthink(p)
	if(p.mo.skin == "sonic")then return end
	local mo,sv = p.mo,p.ssonicvars
	-- Change the color to the super color if not currently rainbow.
	if(p.invincibilitytimer <= (TICRATE*10) and mo.color ~= SKINCOLOR_INVINCFLASH)then mo.color = superColor.getPlayer(p) end
	-- If we aren't cheating then do not continue
	if(p.ssonicvars == nil)then return end
	-- Intro!
	if(sv.transformTics)then
		mo.color = SKINCOLOR_INVINCFLASH
		mo.colorized = true
		mo.frame = $|FF_FULLBRIGHT
		sv.transformTics = $-1
		if(not sv.transformTics)then
			mo.frame = $&~FF_FULLBRIGHT
		end
	end
	-- Warning!
	if(cheaterThisRace ~= 2)then return end
	if(p.rings <= 3)then
		if(leveltime % 2 == 0)then
			mo.color = SKINCOLOR_RED
			mo.colorized = true
		end
	elseif(p.rings <= 10 and leveltime % (TICRATE/4) == 0)then
		mo.color = SKINCOLOR_RED
		mo.colorized = true
	end
end

-- Alright here's the positions for all the hud elements in an easy to access table
ss.ringnumtable = {
	[false] = { -- No Lives
		-- Splitscreen Num
		[0] = { -- 1 Player
			[0] = {35,156},
			add = 20
		},
		[1] = { -- 2 Player
			[0] = {35,61}, -- Left
			[1] = {35,61}, -- Right
			add = 20
		},
		[2] = { -- 3 Player
			[0] = {14,78}, -- Left
			[1] = {303,78}, -- Right
			add = 10
		},
		[3] = { -- 4 Player
			[0] = {14,78}, -- Left
			[1] = {303,78}, -- Right
			add = 10
		}
	},
	[true] = { -- Lives
		-- Splitscreen Num
		[0] = { -- 1 Player
			[0] = {35,156},
			add = 20
		},
		[1] = { -- 2 Player
			[0] = {35,61}, -- Left
			[1] = {35,61}, -- Right
			add = 20
		},
		[2] = { -- 3 Player
			[0] = {14,78}, -- Left
			[1] = {288,78}, -- Right
			add = 10
		},
		[3] = { -- 4 Player
			[0] = {14,78}, -- Left
			[1] = {288,78}, -- Right
			add = 10
		}
	},
}

function ss.hud(v,p,c)
	if(not cheatThisRace)then return end
	if(not p.ssonicvars)then return end
	local sv = p.ssonicvars
	-- Cache font(s) if they don't exist
	ss.patch = $ or {
		ringFont = ssnkPatchString.cache(v,4,-1,"TMFNS","\"'/0123456789"),
		sRingFont = ssnkPatchString.cache(v,4,-1,"PINGF","\"'/0123456789"),
		rivalSprites = {v.cachePatch("K_RIVAL1"),v.cachePatch("K_RIVAL2")}
	}
	-- Draw over Rings
	if(p.rings < 0 or (sv.notSuper and p.rings < 20))then return end
	-- Screen size junk
	local scrw,scrh = v.width(),v.height()
	local dupx,fdupx = v.dupx()
	local dupy,fdupy = v.dupy()
	local scrhw,scrhh = (scrw/(dupx*2))<<FRACBITS,(scrh/(dupy*2))<<FRACBITS
	-- Get view id & offset
	local splitplayer = 0
	local offset = cfChars.getSplitscreenOffset(v,splitplayer)
	offset.flags = ($&(V_SNAPTOLEFT|V_SNAPTORIGHT))|V_SNAPTOLEFT|V_SNAPTOBOTTOM|V_SLIDEIN
	local font = (splitscreen > 1) and ss.patch.sRingFont or ss.patch.ringFont
	-- Position + text
	local lapnum = (cvar_numlaps.value == -1) and mapheaderinfo[gamemap].numlaps or cvar_numlaps.value
	local rpos,rings = ss.ringnumtable[G_GametypeUsesLives()][splitscreen][splitplayer & 1],tostring(p.rings + sv.bonusRings)
	if(p.rings < 10)then rings = "0"..$ end
	-- Color Map
	local colormap = nil
	if(sv.bonusRings >= 130 and p.rings >= 20)then
		colormap = v.getColormap(TC_RAINBOW,cfChars.K_RainbowColor(leveltime/2))
	elseif(p.rings >= 20)then
		colormap = v.getColormap(TC_RAINBOW,SKINCOLOR_YELLOW)
	elseif((leveltime/(TICRATE/4))%2 == 0 and p.rings <= 10)then
		colormap = v.getColormap(TC_RAINBOW,SKINCOLOR_RED)
	end
	-- Lap Offset
	offset.y = abs($)>>FRACBITS * (($ > 0) and 1 or -1)
	if(lapnum == 1)then offset.y = $ + ss.ringnumtable[G_GametypeUsesLives()][splitscreen].add end
	--print(rpos[2] + offset.y)
	ssnkPatchString.drawString(v,rpos[1],rpos[2] + offset.y,font,rings,offset.flags,colormap)
end

--[[ Fake Emeralds (Intro) ]]--

function ss.initIntro(p)
	for i=0,6 do
		local realang = FixedAngle(FRACUNIT * i * 52)
		local emerald,back = P_SpawnMobjFromMobj(p.mo,0,0,0,MT_THOK),P_SpawnMobjFromMobj(p.mo,0,0,0,MT_THOK)
		emerald.state = S_CHAOSEMERALD1
		emerald.supersonicintro = true
		emerald.angle = realang
		emerald.color = SKINCOLOR_CHAOSEMERALD1+i
		emerald.target = p.mo
		emerald.dispoffset = 1
		
		back.state = S_CHAOSEMERALD_UNDER
		back.supersonicintro = true
		back.angle = realang
		back.color = SKINCOLOR_CHAOSEMERALD1+i
		back.target = p.mo
	end
end

addHook("MobjThinker",function(mo)
	if(not mo.supersonicintro)then return end
	-- If the target doesn't exist, die
	if(not mo.target or not mo.target.valid)then
		mo.state = S_NULL
		return
	end
	-- Circle around the player
	local pmo = mo.target
	local dolerp = FixedDiv(min(max(leveltime-(starttime-(TICRATE*3)),0),TICRATE*3)*FRACUNIT,TICRATE*FRACUNIT*3)
	mo.angle = $+ease.linear(dolerp,ANG2,ANGLE_45)
	local newx,newy,newz,newdist,newscale = 0,0,0,0,0
	newscale = ease.linear(dolerp,FRACUNIT/2,FRACUNIT/12)
	mo.scale = FixedMul(newscale,pmo.scale)
	newdist = FixedMul(mo.scale,FRACUNIT*128)
	
	newx = pmo.x + P_ReturnThrustX(pmo,mo.angle,newdist)
	newy = pmo.y + P_ReturnThrustY(pmo,mo.angle,newdist)
	newz = pmo.z + sin(leveltime << 6)
	
	P_MoveOrigin(mo,newx,newy,newz)
	
	-- Remove and create a flash!
	if(leveltime > starttime)then
		if(mo.state == S_CHAOSEMERALD_UNDER)then
			local spark = P_SpawnMobjFromMobj(pmo,0,0,0,MT_EMERALDSPARK)
			spark.color = mo.color
			spark.hitlag = 0
			P_InstaThrust(spark,mo.angle,FRACUNIT*8)
		end
		mo.state = S_NULL
	end
end,MT_THOK)

--[[ Special Ring Touch ]]--

function ss.ringTouch(r,mo)
	if(not cheatThisRace)then return nil end
	if(mo.type ~= MT_PLAYER)then return nil end
	if(not mo.player.ssonicvars or not mo.player.ssonicvars.superInit)then return nil end
	if(cheatThisRace == 2 and mo.player.ssonicvars.bonusRings >= 30)then return nil end
	local p = mo.player
	-- Translation from the source code.
	if(p.pflags & PF_RINGLOCK or r.extravalue1 or r.threshold > 0 
	or P_PlayerInPain(p) or not P_CanPickupItem(p,0))then return nil end
	r.extravalue1 = 1
	r.angle = R_PointToAngle2(mo.x,mo.y,r.x,r.y)
	r.target = mo
	
	r.renderflags = $ & ~RF_DONTDRAW
	r.fuse = 0
	
	p.pickuprings = $ + 1
	
	if(p.rings < 20)then return true end
	p.ssonicvars.bonusRings = $ + 1
	return true
end

--[[ Special Damage ]]--

function ss.killed(p,mo,i,s,d,dt)
	if(not cheatThisRace)then return nil end
	if(p.exiting)then return nil end
	local sv = p.ssonicvars
	if(sv.notSuper)then return nil end
	if(i and i.type == MT_SPBEXPLOSION)then
		-- Force the player to die
		P_DamageMobj(mo,mo,s,99999,DMG_INSTAKILL)
		return nil
	end
	if(dt == DMG_DEATHPIT)then 
		p.ssonicvars.ringBurst = 20
		p.ssonicvars.ticsTilBurst = TICRATE
		return nil 
	end
	if(not (dt == DMG_INSTAKILL or dt == DMG_CRUSHED))then return nil end
	if(cheatThisRace == 2)then
		if(netgame or (splitscreen and not G_GametypeUsesLives()))then
			p.pflags = $|PF_NOCONTEST|PF_ELIMINATED
			p.realtime = $<<FRACBITS
			p.exiting = 1
			if(not netgame)then
				local dead_players = 0
				for i in displayplayers.iterate() do
					if(i.pflags & (PF_NOCONTEST|PF_ELIMINATED))then dead_players = $+1 end
				end
				if(dead_players > splitscreen)then 
					P_DoPlayerExit(p,p.pflags) 
					G_ExitLevel()
				end
			else
				local dead_players = 0
				local iterations = 0
				for i in players.iterate do
					iterations = $+1
					if(not p or not p.valid)then
						dead_players = $+1
						continue
					end
					if(p.spectator or p.exitting)then
						dead_players = $+1
						continue
					end
					if(i.pflags & (PF_NOCONTEST|PF_ELIMINATED))then dead_players = $+1 end
				end
				if(dead_players >= iterations)then 
					P_DoPlayerExit(p,p.pflags) 
					G_ExitLevel()
				end
			end
		else
			p.pflags = $|PF_NOCONTEST|PF_ELIMINATED
			p.realtime = $<<FRACBITS
			P_DoPlayerExit(p,p.pflags)
		end
		return nil
	end
	sv.bonusRings = 0
	sv.notSuper = true
end

--[[ Hooks ]]--
addHook("MapLoad",ss.mapLoad)
chrisHooks.addSkinHook("PlayerThink",ss.think,"ssonic")
chrisHooks.addSkinHook("PreThinkFrame",ss.prethink,"ssonic")
chrisHooks.addSkinHook("PostThinkFrame",ss.postthink,"ssonic")
chrisHooks.addSkinHook("ShouldDamage",ss.killed,"ssonic")
addHook("TouchSpecial",ss.ringTouch,MT_RING)
addHook("TouchSpecial",ss.ringTouch,MT_FLINGRING)
hud.add(ss.hud,"game")