-- Prevent errors.
if(rawget(_G,supercolors_api1))then return end
-- Define super-color related things.
local supercol = {
	default = {},
}
local defualt_super_colors = {}

---@param color_id The color you want to give a super color
---@param super_color_id The color you want to be the super color.
---@return namespace, for chaining.
function supercol.addDefault(color_id,super_color_id)
	defualt_super_colors[color_id] = super_color_id
	return supercol
end

---@param p player_t
---@return Super Color ID
function supercol.getPlayer(p)
	-- Check if player has super color
	if(p.supercolor == "opp")then
		return ColorOpposite(p.skincolor)
	elseif(p.supercolor == nil or p.supercolor == 0 or p.supercolor >= #skincolors or type(p.supercolor) ~= "number")then 
		-- If not, return default (or yellow)
		if(supercol.default[p.skincolor] ~= nil)then
			return supercol.default[p.skincolor]
		end
		return SKINCOLOR_SUPERYELLOW
	end
	return p.supercolor
end

-- command: supercolor
COM_AddCommand("supercolor",function(p,arg)
	local num_arg = tonumber(arg)
	if(arg == nil)then
		CONS_Printf(p,"supercolor <skincolor name or id>: Sets your Super Skincolor.")
		CONS_Printf(p,"Your super color is currently '"..R_GetNameByColor(supercol.getPlayer(p)).."' default is dependent on your SkinColor!")
		CONS_Printf(p,"To get a list of colors, use 'supercolor -list'")
		CONS_Printf(p,"To use your opposite color, use 'supercolor -opp'")
		return
	elseif(string.lower(arg) == "-list")then
		CONS_Printf(p,"Available Skin Colors")
		local i = 1
		while(i < #skincolors)do
			CONS_Printf(p,tostring(i).."	:	'"..R_GetNameByColor(i).."'")
			i = $+1
		end
		return
	elseif(string.lower(arg) == "-opp")then
		p.supercolor = "opp"
		CONS_Printf(p,"supercolor is now '"..R_GetNameByColor(supercol.getPlayer(p)).."'")
		return
	end
	-- If a number is put in
	if(num_arg ~= nil)then
		if(num_arg < 0 or num_arg >= #skincolors)then
			CONS_Printf(p,"Skin color must be within 0 to "..tostring(#skincolors - 1).."!")
			return
		end
		p.supercolor = num_arg
		CONS_Printf(p,"supercolor is now '"..R_GetNameByColor(num_arg).."'")
		return
	end
	-- If literally anything else is put in
	p.supercolor = R_GetColorByName(arg)
	CONS_Printf(p,"supercolor is now '"..tostring(R_GetNameByColor(supercol.getPlayer(p))).."', or number "..tostring(p.supercolor)..".")
end)
-- Allow other scripts to use these functions
rawset(_G,"supercolors_api1",true)
rawset(_G,"superColor",supercol)

if(rawget(_G,"SKINCOLOR_SUPERYELLOW") == nil)then
	-- Add the Super Colors from my awesome mod.
	freeslot(
		"SKINCOLOR_SUPERYELLOW",
		"SKINCOLOR_SUPERORANGE",
		"SKINCOLOR_SUPERRED",
		"SKINCOLOR_SUPERGREEN",
		"SKINCOLOR_SUPERBLUE",
		"SKINCOLOR_SUPERPURPLE",
		"SKINCOLOR_SUPERHYPER",
		"SKINCOLOR_SUPERBLAZE",
		"SKINCOLOR_CHAOTIXVOMIT",
		"SKINCOLOR_LIGHTBULB",
		"SKINCOLOR_SUPERDARK",
		"SKINCOLOR_CRYSTALRED",
		"SKINCOLOR_IHATEYOU",
		"SKINCOLOR_SORETRO",
		"SKINCOLOR_REFLECTIVE")

	-- Defines
	skincolors[SKINCOLOR_SUPERYELLOW] 		= {name = "Super Yellow"		,ramp = {72	,72	,73	,73	,74	,64	,65	,65	,56	,57	,58	,59	,40	,42	,44	,46	},invcolor = SKINCOLOR_BLACK,invshade = 0,chatcolor = V_YELLOWMAP,accessible = true}
	skincolors[SKINCOLOR_SUPERORANGE] 		= {name = "Super Orange"		,ramp = {49	,50	,52	,52	,54	,54	,214,214,215,215,42	,42	,44	,44	,46	,46	},invcolor = SKINCOLOR_BLACK,invshade = 0,chatcolor = V_ORANGEMAP,accessible = true}
	skincolors[SKINCOLOR_SUPERRED] 			= {name = "Super Red"			,ramp = {216,209,210,210,32	,32	,34	,35	,37	,37	,195,195,197,197,199,199},invcolor = SKINCOLOR_BLACK,invshade = 0,chatcolor = V_REDMAP,accessible = true}
	skincolors[SKINCOLOR_SUPERGREEN] 		= {name = "Super Green"			,ramp = {89	,188,188,189,189,100,100,102,102,104,104,106,106,108,108,110},invcolor = SKINCOLOR_BLACK,invshade = 0,chatcolor = V_GREENMAP,accessible = true}
	skincolors[SKINCOLOR_SUPERBLUE] 		= {name = "Super Blue"			,ramp = {129,130,131,131,146,146,147,147,148,148,149,149,165,165,166,168},invcolor = SKINCOLOR_BLACK,invshade = 0,chatcolor = V_BLUEMAP,accessible = true}
	skincolors[SKINCOLOR_SUPERPURPLE] 		= {name = "Super Purple"		,ramp = {160,161,162,162,149,149,151,151,153,153,155,155,157,157,159,153},invcolor = SKINCOLOR_BLACK,invshade = 0,chatcolor = V_PURPLEMAP,accessible = true}
	skincolors[SKINCOLOR_SUPERHYPER] 		= {name = "Hyper"				,ramp = {0,0,2,3,4,5,6,7,8,8,9,10,11,12,13,14},invcolor = SKINCOLOR_BLACK,invshade = 0,chatcolor = V_INVERTMAP,accessible = true}
	skincolors[SKINCOLOR_SUPERBLAZE] 		= {name = "Super Blaze"			,ramp = {52	,53	,54	,35	,36	,36	,37	,37	,38	,39	,40	,41	,42	,43	,44	,45	},invcolor = SKINCOLOR_BLACK,invshade = 0,chatcolor = V_ROSYMAP,accessible = true}
	skincolors[SKINCOLOR_CHAOTIXVOMIT] 		= {name = "Chaotix Vomit"		,ramp = {181,203,244,92	,101,113,112,112,112,113,101,92	,244,203,181,181},invcolor = SKINCOLOR_BLACK,invshade = 0,chatcolor = V_PERIDOTMAP,accessible = true}
	skincolors[SKINCOLOR_LIGHTBULB] 		= {name = "Light Bulb"			,ramp = {16	,17	,18	,19	,20	,21	,22	,23	,24	,25	,26	,27	,28	,29	,30	,31	},invcolor = SKINCOLOR_BLACK,invshade = 0,chatcolor = V_INVERTMAP,accessible = true}
	skincolors[SKINCOLOR_SUPERDARK] 		= {name = "Super Dark"			,ramp = {156,157,158,158,159,159,253,253,253,253,254,254,254,254,31	,31	},invcolor = SKINCOLOR_BLACK,invshade = 0,chatcolor = V_INVERTMAP,accessible = true}
	skincolors[SKINCOLOR_CRYSTALRED] 		= {name = "Crystal Red"			,ramp = {40, 41, 42, 46, 45, 44, 42, 41, 41, 39, 38, 37, 36, 34, 33, 32 },invcolor = SKINCOLOR_BLACK,invshade = 0,chatcolor = V_REDMAP,accessible = true}
	skincolors[SKINCOLOR_IHATEYOU] 			= {name = "Koopa Works Alone"	,ramp = {39, 39, 40, 40, 41, 41, 42, 42, 43, 43, 44, 44, 45, 45, 46, 47 },invcolor = SKINCOLOR_WHITE,invshade = 12,chatcolor = V_REDMAP,accessible = true}
	skincolors[SKINCOLOR_SORETRO] 			= {name = "Coin Block"			,ramp = {39, 39, 40, 40, 41, 41, 42, 42, 43, 43, 44, 44, 45, 45, 46, 47 },invcolor = SKINCOLOR_BLACK,invshade = 8,chatcolor = V_BROWNMAP,accessible = true}
	skincolors[SKINCOLOR_REFLECTIVE] 		= {name = "Reflective"			,ramp = {39, 39, 40, 40, 41, 41, 42, 42, 43, 43, 44, 44, 45, 45, 46, 47 },invcolor = SKINCOLOR_BLACK,invshade = 0,chatcolor = V_BLUEMAP,accessible = true}

	-- Base colors
	animatedSkinColor.makeAnimated(SKINCOLOR_SUPERYELLOW,4).
	addRamp(SKINCOLOR_SUPERYELLOW,
	{72	,72	,73	,73	,74	,64	,65	,65	,56	,57	,58	,59	,40	,42	,44	,46	},
	{83	,72	,72	,73	,73	,64	,64	,65	,65	,56	,57	,58	,59	,40	,42	,44	},
	{81	,82	,83	,83	,72	,72	,73	,73	,73	,73	,64	,65	,56	,57	,58	,59	},
	{0	,80	,81	,82	,83	,72	,72	,73	,73	,73	,73	,64	,64	,54	,54	,56	},
	{0	,0	,0	,0	,0	,0	,0	,0	,81	,81	,81	,81	,73	,73	,73	,73	},
	{0	,80	,81	,82	,83	,72	,72	,73	,73	,73	,73	,64	,64	,54	,54	,56	},
	{81	,82	,83	,83	,72	,72	,73	,73	,73	,73	,64	,65	,56	,57	,58	,59	},
	{83	,72	,72	,73	,73	,64	,64	,65	,65	,56	,57	,58	,59	,40	,42	,44	}).
	makeAnimated(SKINCOLOR_SUPERORANGE,4).
	addRamp(SKINCOLOR_SUPERORANGE,
	{49	,50	,52	,52	,54	,54	,214,214,215,215,42	,42	,44	,44	,46	,46	},
	{48	,48	,49	,49	,50	,52	,52	,54	,54	,214,214,215,215,42	,42	,44	},
	{80	,48	,48	,49	,49	,50	,50	,52	,52	,54	,54	,214,214,215,215,42	},
	{0	,80	,81	,48	,48	,49	,49	,50	,50	,52	,52	,54	,54	,214,214,215},
	{0	,0	,0	,0	,0	,0	,48	,48	,51	,51	,51	,51	,53	,53	,53	,53	},
	{0	,80	,81	,48	,48	,49	,49	,50	,50	,52	,52	,54	,54	,214,214,215},
	{80	,48	,48	,49	,49	,50	,50	,52	,52	,54	,54	,214,214,215,215,42	},
	{48	,48	,49	,49	,50	,52	,52	,54	,54	,214,214,215,215,42	,42	,44	}).
	makeAnimated(SKINCOLOR_SUPERRED,4).
	addRamp(SKINCOLOR_SUPERRED,
	{216,209,210,210,32	,32	,34	,35	,37	,37	,195,195,197,197,199,199},
	{208,216,209,210,210,32	,32	,34	,35	,37	,37	,195,195,197,197,197},
	{208,216,216,209,209,210,210,32	,32	,34	,35	,37	,37	,195,195,195},
	{0	,208,216,216,209,209,210,210,32	,32	,34	,34	,35	,35	,37	,37	},
	{0	,0	,0	,0	,0	,0	,208,208,210,210,210,210,35	,35	,35	,35	},
	{0	,208,216,216,209,209,210,210,32	,32	,34	,34	,35	,35	,37	,37	},
	{208,216,216,209,209,210,210,32	,32	,34	,35	,37	,37	,195,195,195},
	{208,216,209,210,210,32	,32	,34	,35	,37	,37	,195,195,197,197,197}).
	makeAnimated(SKINCOLOR_SUPERGREEN,4).
	addRamp(SKINCOLOR_SUPERGREEN,
	{89	,188,188,189,189,100,100,102,102,104,104,106,106,108,108,110},
	{88	,89	,89	,188,188,189,189,100,100,102,102,104,104,106,106,108},
	{0	,88	,88	,89	,89	,188,188,189,189,100,100,102,102,104,104,106},
	{0	,88	,88	,88	,88	,89	,89	,188,188,189,189,100,100,102,102,104},
	{0	,0	,0	,0	,0	,0	,88	,88	,188,188,188,188,100,100,100,100},
	{0	,88	,88	,88	,88	,89	,89	,188,188,189,189,100,100,102,102,104},
	{0	,88	,88	,89	,89	,188,188,189,189,100,100,102,102,104,104,106},
	{88	,89	,89	,188,188,189,189,100,100,102,102,104,104,106,106,108}).
	makeAnimated(SKINCOLOR_SUPERBLUE,4).
	addRamp(SKINCOLOR_SUPERBLUE,
	{129,130,131,131,146,146,147,147,148,148,149,149,165,165,166,168},
	{128,129,130,130,131,131,146,146,147,147,148,148,149,149,165,166},
	{0	,128,129,129,130,130,131,131,146,146,147,147,148,149,165,165},
	{0	,0	,128,128,129,129,130,130,131,131,146,146,147,147,148,148},
	{0	,0	,0	,0	,0	,0	,128,128,130,130,130,130,147,147,147,147},
	{0	,0	,128,128,129,129,130,130,131,131,146,146,147,147,148,148},
	{0	,128,129,129,130,130,131,131,146,146,147,147,148,149,165,165},
	{128,129,130,130,131,131,146,146,147,147,148,148,149,149,165,166}).
	makeAnimated(SKINCOLOR_SUPERPURPLE,4).
	addRamp(SKINCOLOR_SUPERPURPLE,
	{160,161,162,162,149,149,151,151,153,153,155,155,157,157,159,153},
	{176,160,161,161,162,162,149,149,151,151,153,153,155,155,157,159},
	{0	,176,176,160,160,161,161,162,162,149,149,151,151,153,153,155},
	{0	,0	,0	,176,176,160,160,161,161,162,162,149,149,151,151,153},
	{0	,0	,0	,0	,0	,0	,176,176,178,178,178,178,180,180,180,180},
	{0	,0	,0	,176,176,160,160,161,161,162,162,149,149,151,151,153},
	{0	,176,176,160,160,161,161,162,162,149,149,151,151,153,153,155},
	{176,160,161,161,162,162,149,149,151,151,153,153,155,155,157,159})
	-- Sharb: Hyper
	animatedSkinColor.makeAnimated(SKINCOLOR_SUPERHYPER,4).
	addRamp(SKINCOLOR_SUPERHYPER,
	{0,0,2,3,4,5,6,7,8,8,9,10,11,12,13,14},
	{0,0,0,0,129,130,140,140,140,140,140,141,142,142,143,16},
	{0,0,144,128,129,130,131,140,141,132,132,133,134,135,136,137},
	{0,0,252,2,5,6,9,9,11,170,12,13,16,19,137,138},
	{0,0,252,48,50,209,32,32,32,212,213,214,69,70,197,26},
	{0,0,252,208,84,216,210,210,210,212,212,213,229,233,197,26},
	{0,0,252,80,83,48,218,218,218,222,222,224,77,78,197,26},
	{0,0,80,80,81,88,89,89,89,90,91,190,116,106,235,26},
	{0,0,2,3,2,4,6,6,90,7,9,91,103,93,245,19})
	-- ChrisFurry: Super Blaze
	animatedSkinColor.makeAnimated(SKINCOLOR_SUPERBLAZE,4).
	addRamp(SKINCOLOR_SUPERBLAZE,
	{52	,53	,54	,35	,36	,36	,37	,37	,38	,39	,40	,41	,42	,43	,44	,45	},
	{81	,64	,51	,51	,52	,52	,53	,36	,37	,38	,39	,40	,41	,42	,43	,44	},
	{80	,81	,64	,64	,51	,51	,52	,52	,53	,53	,36	,36	,37	,38	,39	,40	},
	{0	,80	,81	,81	,64	,64	,51	,51	,52	,52	,53	,53	,54	,39	,40	,42	},
	{0	,0	,0	,0	,80	,80	,81	,81	,64	,64	,51	,52	,53	,54	,39	,40	},
	{0	,80	,81	,81	,64	,64	,51	,51	,52	,52	,53	,53	,54	,39	,40	,42	},
	{80	,81	,64	,64	,51	,51	,52	,52	,53	,53	,36	,36	,37	,38	,39	,40	},
	{81	,64	,51	,51	,52	,52	,53	,36	,37	,38	,39	,40	,41	,42	,43	,44	})
	-- ChrisFurry: Chaotix Vomit
	animatedSkinColor.makeAnimated(SKINCOLOR_CHAOTIXVOMIT,4).
	addRamp(SKINCOLOR_CHAOTIXVOMIT,
	{181,203,244,92	,101,113,112,112,112,113,101,92	,244,203,181,181},
	{181,181,203,244,92	,101,113,112,112,112,113,101,92	,244,203,181},
	{181,181,181,203,244,92	,101,113,112,112,112,113,101,92	,244,203},
	{203,181,181,181,203,244,92	,101,113,112,112,112,113,101,92	,244},
	{244,203,181,181,181,203,244,92	,101,113,112,112,112,113,101,92	},
	{92	,244,203,181,181,181,203,244,92	,101,113,112,112,112,113,101},
	{101,92	,244,203,181,181,181,203,244,92	,101,113,112,112,112,113},
	{113,101,92	,244,203,181,181,181,203,244,92	,101,113,112,112,112},
	{112,113,101,92	,244,203,181,181,181,203,244,92	,101,113,112,112},
	{112,112,113,101,92	,244,203,181,181,181,203,244,92	,101,113,112},
	{112,112,112,113,101,92	,244,203,181,181,181,203,244,92	,101,113},
	{113,112,112,112,113,101,92	,244,203,181,181,181,203,244,92	,101},
	{101,113,112,112,112,113,101,92	,244,203,181,181,181,203,244,92	},
	{92	,101,113,112,112,112,113,101,92	,244,203,181,181,181,203,244},
	{244,92	,101,113,112,112,112,113,101,92	,244,203,181,181,181,203},
	{203,244,92	,101,113,112,112,112,113,101,92	,244,203,181,181,181})
	-- ChrisFurry: Light Bulb
	animatedSkinColor.makeAnimated(SKINCOLOR_LIGHTBULB,3).
	addRamp(SKINCOLOR_LIGHTBULB,
	{16	,17	,18	,19	,20	,21	,22	,23	,24	,25	,26	,27	,28	,29	,30	,31	},
	{13	,13	,14	,14	,15	,16	,17	,18	,19	,20	,21	,22	,23	,24	,25	,26	},
	{87	,87	,77	,13	,13	,16	,16	,17	,17	,18	,18	,19	,19	,20	,20	,21	},
	{84	,85	,86	,86	,86	,13	,13	,14	,14	,15	,15	,16	,16	,17	,17	,17	},
	{83	,83	,84	,84	,85	,85	,86	,86	,87	,87	,87	,87	,87	,87	,87	,87	},
	{81	,81	,82	,72	,72	,64	,64	,65	,65	,66	,66	,67	,67	,68	,68	,69	},
	{80	,80	,81	,81	,81	,82	,82	,82	,83	,72	,73	,74	,75	,67	,67	,68	},
	{81	,81	,82	,72	,72	,64	,64	,65	,65	,66	,66	,67	,67	,68	,68	,69	},
	{83	,83	,84	,84	,85	,85	,86	,86	,87	,87	,87	,87	,87	,87	,87	,87	},
	{84	,85	,86	,86	,86	,13	,13	,14	,14	,15	,15	,16	,16	,17	,17	,17	},
	{87	,87	,77	,13	,13	,16	,16	,17	,17	,18	,18	,19	,19	,20	,20	,21	},
	{13	,13	,14	,14	,15	,16	,17	,18	,19	,20	,21	,22	,23	,24	,25	,26	})
	-- ChrisFurry: Super Dark
	animatedSkinColor.makeAnimated(SKINCOLOR_SUPERDARK,4).
	addRamp(SKINCOLOR_SUPERDARK,
	{156,157,158,158,159,159,253,253,253,253,254,254,254,254,31	,31	},
	{155,155,156,156,157,157,158,159,253,253,253,254,254,254,31	,31	},
	{136,154,154,155,155,156,157,158,159,253,253,254,254,254,31	,31	},
	{135,135,136,136,154,154,155,156,157,158,159,253,253,254,254,31	},
	{133,134,135,135,136,136,154,154,155,156,157,158,159,253,254,31	},
	{135,135,136,136,154,154,155,156,157,158,159,253,253,254,254,31	},
	{136,154,154,155,155,156,157,158,159,253,253,254,254,254,31	,31	},
	{155,155,156,156,157,157,158,159,253,253,253,254,254,254,31	,31	})
	-- SuperSonicNK: Crystal Red
	animatedSkinColor.makeAnimated(SKINCOLOR_CRYSTALRED,4).
	addRamp(SKINCOLOR_CRYSTALRED,
	{40, 41, 42, 46, 45, 44, 42, 41, 41, 39, 38, 37, 36, 34, 33, 32},
	{37, 40, 41, 45, 44, 43, 41, 40, 40, 38, 38, 36, 35, 34, 32, 48},
	{34, 37, 40, 44, 43, 41, 40, 40, 38, 38, 36, 35, 34, 32, 48, 0},
	{37, 40, 41, 45, 44, 43, 41, 40, 40, 38, 38, 36, 35, 34, 32, 48})
	-- ChrisFurry: Koopa works alone (aka I HATE YOU)
	animatedSkinColor.makeAnimated(SKINCOLOR_IHATEYOU,3).
	addRamp(SKINCOLOR_IHATEYOU,
	{39, 39, 40, 40, 41, 41, 42, 42, 43, 43, 44, 44, 45, 45, 46, 47},
	{47, 39, 39, 40, 40, 41, 41, 42, 42, 43, 43, 44, 44, 45, 45, 46},
	{46, 47, 39, 39, 40, 40, 41, 41, 42, 42, 43, 43, 44, 44, 45, 45},
	{45, 46, 47, 39, 39, 40, 40, 41, 41, 42, 42, 43, 43, 44, 44, 45},
	{45, 45, 46, 47, 39, 39, 40, 40, 41, 41, 42, 42, 43, 43, 44, 44},
	{44, 45, 45, 46, 47, 39, 39, 40, 40, 41, 41, 42, 42, 43, 43, 44},
	{44, 44, 45, 45, 46, 47, 39, 39, 40, 40, 41, 41, 42, 42, 43, 43},
	{43, 44, 44, 45, 45, 46, 47, 39, 39, 40, 40, 41, 41, 42, 42, 43},
	{43, 43, 44, 44, 45, 45, 46, 47, 39, 39, 40, 40, 41, 41, 42, 42},
	{42, 43, 43, 44, 44, 45, 45, 46, 47, 39, 39, 40, 40, 41, 41, 42},
	{42, 42, 43, 43, 44, 44, 45, 45, 46, 47, 39, 39, 40, 40, 41, 41},
	{41, 42, 42, 43, 43, 44, 44, 45, 45, 46, 47, 39, 39, 40, 40, 41},
	{41, 41, 42, 42, 43, 43, 44, 44, 45, 45, 46, 47, 39, 39, 40, 40},
	{40, 41, 41, 42, 42, 43, 43, 44, 44, 45, 45, 46, 47, 39, 39, 40},
	{40, 40, 41, 41, 42, 42, 43, 43, 44, 44, 45, 45, 46, 47, 39, 39},
	{39, 40, 40, 41, 41, 42, 42, 43, 43, 44, 44, 45, 45, 46, 47, 39})
	-- ChrisFurry: Coin Block
	animatedSkinColor.makeAnimated(SKINCOLOR_SORETRO,10).
	addRamp(SKINCOLOR_SORETRO,
	{57, 59, 69, 70,198,198,199,199,253,253,253,253,199,198, 70, 59},
	{54, 54, 57, 57, 59, 59, 69, 69, 70, 70,198,198,198, 70, 70, 59},
	{80, 82,218,219,221,221, 54, 57, 59, 69, 70,198,198, 70, 59, 57},
	{54, 54, 57, 57, 59, 59, 69, 69, 70, 70,198,198,198, 70, 70, 59})
	-- ChrisFurry: Reflective
	animatedSkinColor.makeAnimated(SKINCOLOR_REFLECTIVE,5).
	addRamp(SKINCOLOR_REFLECTIVE,
	{129,131,134,149,151,153,154,167,168,169,169,169,168,167,154,151},
	{131,134,149,151,153,154,167,168,169,169,169,168,167,154,153,151},
	{149,151,153,154,167,168,169,253,253,169,168,167,154,153,151,149},
	{151,153,154,167,168,169,169,169,168,167,154,153,151,149,134,131},
	{151,154,167,168,169,169,169,168,167,154,153,151,149,134, 131,129},
	{151,153,154,167,168,169,169,169,168,167,154,153,151,149,134,131},
	{149,151,153,154,167,168,169,253,253,169,168,167,154,153,151,149},
	{131,134,149,151,153,154,167,168,169,169,169,168,167,154,153,151})
end
-- Add defaults for the base colors.
superColor.addDefault(SKINCOLOR_FAIRY		,SKINCOLOR_SUPERRED)
.addDefault(SKINCOLOR_ARTICHOKE	,SKINCOLOR_SUPERGREEN)
.addDefault(SKINCOLOR_PIGEON		,SKINCOLOR_SUPERBLUE)

.addDefault(SKINCOLOR_SEPIA		,SKINCOLOR_SUPERORANGE)
.addDefault(SKINCOLOR_BEIGE		,SKINCOLOR_SUPERORANGE)
.addDefault(SKINCOLOR_CARAMEL		,SKINCOLOR_SUPERORANGE)
.addDefault(SKINCOLOR_PEACH		,SKINCOLOR_SUPERORANGE)
.addDefault(SKINCOLOR_BROWN		,SKINCOLOR_SUPERORANGE)
.addDefault(SKINCOLOR_LEATHER		,SKINCOLOR_SUPERORANGE)

.addDefault(SKINCOLOR_PINK			,SKINCOLOR_SUPERRED)
.addDefault(SKINCOLOR_ROSE			,SKINCOLOR_SUPERRED)
.addDefault(SKINCOLOR_CINNAMON		,SKINCOLOR_SUPERRED)
.addDefault(SKINCOLOR_RUBY			,SKINCOLOR_SUPERRED)
.addDefault(SKINCOLOR_RASPBERRY	,SKINCOLOR_SUPERRED)
.addDefault(SKINCOLOR_RED			,SKINCOLOR_SUPERRED)
.addDefault(SKINCOLOR_CRIMSON		,SKINCOLOR_SUPERRED)
.addDefault(SKINCOLOR_MAROON		,SKINCOLOR_SUPERRED)

.addDefault(SKINCOLOR_SCARLET		,SKINCOLOR_SUPERORANGE)
.addDefault(SKINCOLOR_DAWN			,SKINCOLOR_SUPERORANGE)
.addDefault(SKINCOLOR_SUNSLAM		,SKINCOLOR_SUPERORANGE)
.addDefault(SKINCOLOR_CREAMSICLE	,SKINCOLOR_SUPERORANGE)
.addDefault(SKINCOLOR_ORANGE		,SKINCOLOR_SUPERORANGE)
.addDefault(SKINCOLOR_ROSEWOOD		,SKINCOLOR_SUPERORANGE)

.addDefault(SKINCOLOR_TANGERINE	,SKINCOLOR_SUPERBLUE)
.addDefault(SKINCOLOR_TAN			,SKINCOLOR_SUPERBLUE)
.addDefault(SKINCOLOR_CREAM		,SKINCOLOR_SUPERBLUE)
.addDefault(SKINCOLOR_GOLD			,SKINCOLOR_SUPERBLUE)
.addDefault(SKINCOLOR_ROYAL		,SKINCOLOR_SUPERBLUE)
.addDefault(SKINCOLOR_BRONZE		,SKINCOLOR_SUPERBLUE)
.addDefault(SKINCOLOR_COPPER		,SKINCOLOR_SUPERBLUE)
.addDefault(SKINCOLOR_YELLOW		,SKINCOLOR_SUPERBLUE)

.addDefault(SKINCOLOR_MUSTARD		,SKINCOLOR_SUPERRED)

.addDefault(SKINCOLOR_BANANA		,SKINCOLOR_SUPERBLUE)
.addDefault(SKINCOLOR_OLIVE		,SKINCOLOR_SUPERBLUE)

.addDefault(SKINCOLOR_CROCODILE	,SKINCOLOR_SUPERPURPLE)
.addDefault(SKINCOLOR_PERIDOT		,SKINCOLOR_SUPERPURPLE)
.addDefault(SKINCOLOR_LIME			,SKINCOLOR_SUPERPURPLE)
.addDefault(SKINCOLOR_HANDHELD		,SKINCOLOR_SUPERPURPLE)
.addDefault(SKINCOLOR_TEA			,SKINCOLOR_SUPERPURPLE)
.addDefault(SKINCOLOR_PISTACHIO	,SKINCOLOR_SUPERPURPLE)
.addDefault(SKINCOLOR_MOSS			,SKINCOLOR_SUPERPURPLE)
.addDefault(SKINCOLOR_CAMOUFLAGE	,SKINCOLOR_SUPERPURPLE)
.addDefault(SKINCOLOR_MINT			,SKINCOLOR_SUPERPURPLE)
.addDefault(SKINCOLOR_GREEN		,SKINCOLOR_SUPERPURPLE)
.addDefault(SKINCOLOR_PINETREE		,SKINCOLOR_SUPERPURPLE)
.addDefault(SKINCOLOR_TURTLE		,SKINCOLOR_SUPERPURPLE)
.addDefault(SKINCOLOR_SWAMP		,SKINCOLOR_SUPERPURPLE)
.addDefault(SKINCOLOR_DREAM		,SKINCOLOR_SUPERPURPLE)
.addDefault(SKINCOLOR_PLAGUE		,SKINCOLOR_SUPERPURPLE)
.addDefault(SKINCOLOR_EMERALD		,SKINCOLOR_SUPERPURPLE)

.addDefault(SKINCOLOR_ALGAE		,SKINCOLOR_SUPERBLUE)
.addDefault(SKINCOLOR_AQUAMARINE	,SKINCOLOR_SUPERBLUE)
.addDefault(SKINCOLOR_TURQUOISE	,SKINCOLOR_SUPERBLUE)
.addDefault(SKINCOLOR_TEAL			,SKINCOLOR_SUPERBLUE)
.addDefault(SKINCOLOR_CYAN			,SKINCOLOR_SUPERBLUE)
.addDefault(SKINCOLOR_CERULEAN		,SKINCOLOR_SUPERBLUE)
.addDefault(SKINCOLOR_NAVY			,SKINCOLOR_SUPERBLUE)
.addDefault(SKINCOLOR_PLATINUM		,SKINCOLOR_SUPERBLUE)
.addDefault(SKINCOLOR_SLATE		,SKINCOLOR_SUPERBLUE)
.addDefault(SKINCOLOR_STEEL		,SKINCOLOR_SUPERBLUE)

.addDefault(SKINCOLOR_RUST			,SKINCOLOR_SUPERRED)
.addDefault(SKINCOLOR_WRISTWATCH	,SKINCOLOR_SUPERRED)

.addDefault(SKINCOLOR_THISTLE		,SKINCOLOR_SUPERGREEN)
.addDefault(SKINCOLOR_PURPLE		,SKINCOLOR_SUPERGREEN)
.addDefault(SKINCOLOR_PASTEL		,SKINCOLOR_SUPERGREEN)
.addDefault(SKINCOLOR_MOONSET		,SKINCOLOR_SUPERGREEN)
.addDefault(SKINCOLOR_DUSK			,SKINCOLOR_SUPERGREEN)
.addDefault(SKINCOLOR_VIOLET		,SKINCOLOR_SUPERGREEN)
.addDefault(SKINCOLOR_MAGENTA		,SKINCOLOR_SUPERGREEN)
.addDefault(SKINCOLOR_FUCHSIA		,SKINCOLOR_SUPERGREEN)

.addDefault(SKINCOLOR_TOXIC		,SKINCOLOR_SUPERPURPLE)
.addDefault(SKINCOLOR_MAUVE		,SKINCOLOR_SUPERBLUE)

.addDefault(SKINCOLOR_LAVENDER		,SKINCOLOR_SUPERGREEN)
.addDefault(SKINCOLOR_BYZANTIUM	,SKINCOLOR_SUPERGREEN)

.addDefault(SKINCOLOR_POMEGRANATE	,SKINCOLOR_SUPERRED)
.addDefault(SKINCOLOR_LILAC		,SKINCOLOR_SUPERRED)
.addDefault(SKINCOLOR_BLOSSOM		,SKINCOLOR_SUPERRED)

.addDefault(SKINCOLOR_TAFFY		,SKINCOLOR_SUPERPURPLE)